@@ -16,8 +16,7 @@
  */
 #include <config.h>
 #include <string.h>
-#include <gobject/gsignal.h>
-#include <gobject/gmarshal.h>
+#include <glib-object.h>
 #include <bonobo/Bonobo.h>
 #include <bonobo/bonobo-main.h>
 #include <bonobo/bonobo-types.h>
